@@ -1,7 +1,7 @@
 /***
   This file is part of PaSystray
 
-  Copyright (C) 2011-2015  Christoph Gysin
+  Copyright (C) 2011-2016  Christoph Gysin
 
   PaSystray is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
@@ -26,8 +26,8 @@
 #include "notify.h"
 
 void notify_initialize(){}
-notify_handle_t notify(const char* msg, const char* body, const char* icon){ return 0; }
-void notify_update(notify_handle_t h, const char* msg, const char* body, const char* icon){}
+notify_handle_t notify(const char* msg, const char* body, const char* icon, gint value){ return 0; }
+void notify_update(notify_handle_t h, const char* msg, const char* body, const char* icon, gint value){}
 
 #else
 
@@ -51,6 +51,8 @@ void notify_show(NotifyNotification* n)
 
 notify_handle_t notify(const char* msg, const char* body, const char* icon, gint value)
 {
+    if(!icon)
+        icon = "audio-card";
     NotifyNotification* n = notify_notification_new(msg, body, icon);
     notify_notification_set_urgency(n, NOTIFY_URGENCY_LOW);
     notify_notification_set_timeout(n, 2000); // timeout in ms
@@ -62,6 +64,8 @@ notify_handle_t notify(const char* msg, const char* body, const char* icon, gint
 
 void notify_update(notify_handle_t h, const char* msg, const char* body, const char* icon, gint value)
 {
+    if(!icon)
+        icon = "audio-card";
     NotifyNotification* n = (NotifyNotification*) h;
     notify_notification_set_timeout(n, 2000); // timeout in ms
     if(value > -1)
