@@ -1,7 +1,7 @@
 /***
   This file is part of PaSystray
 
-  Copyright (C) 2011-2015  Christoph Gysin
+  Copyright (C) 2011-2016  Christoph Gysin
 
   PaSystray is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
@@ -102,14 +102,21 @@ void pulseaudio_context_state_cb(pa_context* c, void* userdata)
 
         case PA_CONTEXT_READY:
         {
-            char* tooltip = context_info_str(context);
-            char* escaped = g_markup_escape_text(tooltip, -1);
-            char* markup = g_strdup_printf(
+            if(mis->settings.icon_tooltip)
+            {
+                char* tooltip = context_info_str(context);
+                char* escaped = g_markup_escape_text(tooltip, -1);
+                char* markup = g_strdup_printf(
                     "<span font_family=\"monospace\" font_size=\"x-small\">%s</span>", escaped);
-            systray_impl_set_tooltip(mis->systray, markup);
-            g_free(escaped);
-            g_free(tooltip);
-            g_free(markup);
+                systray_impl_set_tooltip(mis->systray, markup);
+                g_free(escaped);
+                g_free(tooltip);
+                g_free(markup);
+            }
+            else
+            {
+                systray_impl_set_has_tooltip(mis->systray, FALSE);
+            }
 
             pa_context_set_subscribe_callback(context, pulseaudio_event_cb, mis);
             pa_operation_unref(pa_context_subscribe(context,
@@ -378,9 +385,9 @@ void pulseaudio_sink_add(const pa_sink_info* i, int is_last, void* userdata, gbo
     menu_info_t* mi = userdata;
     menu_infos_t* mis = mi->menu_infos;
 
-    if(is_new && mis->settings.notify != NOTIFY_NEVER)
+    if(is_new && mis->settings.n_new)
     {
-        gchar* msg = g_strdup_printf("new sink \"%s\"", i->description);
+        gchar* msg = g_strdup_printf("New sink \"%s\"", i->description);
         notify(msg, i->name, NULL, -1);
         g_free(msg);
     }
@@ -426,9 +433,9 @@ void pulseaudio_source_add(const pa_source_info* i, int is_last, void* userdata,
     if(!mis->settings.monitors && class && g_str_equal(class, "monitor"))
         return;
 
-    if(is_new && mis->settings.notify != NOTIFY_NEVER)
+    if(is_new && mis->settings.n_new)
     {
-        gchar* msg = g_strdup_printf("new source \"%s\"", i->description);
+        gchar* msg = g_strdup_printf("New source \"%s\"", i->description);
         notify(msg, i->name, NULL, -1);
         g_free(msg);
     }
